@@ -8,8 +8,7 @@ use SDL::App;
 use SDL::Event;
 use SDL::OpenGL;
 
-my $app = new SDL::App	-w => 800, -h => 600, -d => 24, 
-			-gl => 1, -r => 8, -g => 8, -b => 8;
+my $app = new SDL::App	-w => 800, -h => 600, -d => 16, -gl => 1;
 
 my @points = (  [-4.0, -4.0,  0.0 ],
 		[-2.0,  4.0,  0.0 ],
